from setuptools import setup, find_packages

setup(
    name='getFunctionTest',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'getFileTest = src.functionTest:getFunction'
        ]
    },
    author_email='email@gmail.com',
    version='0.0.4',
    description='Test buat library python',
    author='sinbad',
    license='MIT',
    install_requires=[],
    setup_requires=['pytest-runner'],
    tests_require=['pytest'],
    test_suite='test',
)



import argparse

parser = argparse.ArgumentParser()
parser.add_argument('name', type=str)
parser.add_argument('age', type=str)
args = parser.parse_args()


def getFunction(name, age):
    text = "My name is "+name+" and i'am " + age + " years old"
    return text


if __name__ == '__main__':
    print(getFunction(args.name, args.age))
